@@ -337,8 +337,8 @@ System.out.println("pad value="+longitude.getPadValue()+" status="+cdf.getStatus
 
           // Entry.create(validMin, longitude.getID(), CDF_INT2,
           //             new Short((short)10));
-          Entry.create(validMin, longitude.getID(), CDF_CHAR,
-                       "Test by David");
+          Entry.create(validMin, longitude.getID(), CDF_INT2,
+                       new Short((short)-10));
           latitude.putEntry(validMin, CDF_INT2, new Short((short)20));
           System.out.println("\tAdded VALIDMIN entries.");
 
@@ -637,7 +637,7 @@ System.out.println("pad value="+longitude.getPadValue()+" status="+cdf.getStatus
           double epData  = Epoch.compute(1999, 3, 5, 5, 6, 7, 100),
                  epData1 = Epoch.compute(1998, 1, 2, 3, 4, 5, 666);
           String e0 = Epoch.encode(epData1);
-          double p0 = Epoch.parse(e0);
+          double p0 = Epoch.toParse(e0);
 
           ep.putSingleData(0L, new long[] {0}, new Double(epData)); 
           ep.putSingleData(1L, new long[] {0}, new Double(p0)); 
@@ -699,11 +699,11 @@ System.out.println("pad value="+longitude.getPadValue()+" status="+cdf.getStatus
           /*  Add tt2000 data  */
           /*********************/
           
-          String dateTime = new String("2008-12-31T23:59:58.123456789");
+          String dateTime = new String("2015-06-30T23:59:58.123456789");
           long [] nanosecs = new long[5];
           long nansecSinceJ2000;
           try {
-            nansecSinceJ2000 = CDFTT2000.fromUTCstring(dateTime);
+            nansecSinceJ2000 = CDFTT2000.toParse(dateTime);
           } catch (CDFException ex) {
             nansecSinceJ2000 = 0;
           }
